pub struct PathNode {
pub block: usize,
pub children: Vec<PathNode>,
pub is_path_end: bool,
}Expand description
A node in a PathTree trie.
block is the MIR block index for this node. children holds
successor blocks that appear after block in at least one stored
path. is_path_end is true when some path terminates at this
node (i.e. this block is a CFG terminator for that path).
Fields
block: usizechildren: Vec<PathNode>is_path_end: boolImplementations